#!/bin/bash
# AI Moji Font Generator Setup Script

set -e

echo "🚀 AI Moji Font Generator セットアップ開始"
echo "======================================"

# Python バージョンチェック
echo "🐍 Python バージョンチェック..."
python3 --version || {
    echo "❌ Python 3 が見つかりません"
    echo "   Python 3.6 以上をインストールしてください"
    exit 1
}

# pip が利用可能かチェック
echo "📦 pip チェック..."
python3 -m pip --version || {
    echo "❌ pip が見つかりません"
    echo "   pip をインストールしてください"
    exit 1
}

# FontForge インストール (macOS)
if [[ "$OSTYPE" == "darwin"* ]]; then
    echo "🍎 macOS環境を検出"
    if ! command -v fontforge &> /dev/null; then
        echo "🔧 FontForge をインストール中..."
        if command -v brew &> /dev/null; then
            brew install fontforge
        else
            echo "❌ Homebrew が見つかりません"
            echo "   Homebrewをインストールしてから再実行してください:"
            echo "   /bin/bash -c \"\$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/HEAD/install.sh)\""
            exit 1
        fi
    else
        echo "✅ FontForge インストール済み"
    fi
fi

# FontForge インストール (Ubuntu/Debian)
if [[ "$OSTYPE" == "linux-gnu"* ]]; then
    echo "🐧 Linux環境を検出"
    if ! command -v fontforge &> /dev/null; then
        echo "🔧 FontForge をインストール中..."
        sudo apt-get update
        sudo apt-get install -y fontforge python3-fontforge
    else
        echo "✅ FontForge インストール済み"
    fi
fi

# Python依存関係インストール
echo "📚 Python 依存関係をインストール中..."
python3 -m pip install -r requirements.txt

# ディレクトリ構造確認
echo "📁 ディレクトリ構造確認..."
SVG_DIR="../../svg"
if [ ! -d "$SVG_DIR" ]; then
    echo "⚠️  SVGディレクトリが見つかりません: $SVG_DIR"
    echo "   ai.mojiプロジェクトのルートディレクトリで実行していることを確認してください"
fi

SVG_COUNT=$(find "$SVG_DIR" -name "*.svg" 2>/dev/null | wc -l || echo "0")
echo "   SVGファイル数: $SVG_COUNT"

# 実行権限設定
echo "🔐 実行権限設定..."
chmod +x build.py

# テストビルド
echo "🧪 テストビルド実行..."
python3 build.py --clean
if python3 build.py --font-only; then
    echo "✅ テストビルド成功!"
else
    echo "❌ テストビルドに失敗しました"
    exit 1
fi

echo ""
echo "🎉 セットアップ完了!"
echo "======================================"
echo ""
echo "📋 使用方法:"
echo "   python3 build.py                 # 全体ビルド"
echo "   python3 build.py --font-only     # フォントのみ"
echo "   python3 build.py --css-only      # CSSのみ"
echo "   python3 build.py --package-only  # パッケージングのみ"
echo "   python3 build.py --clean         # クリーンアップ"
echo ""
echo "📁 出力ディレクトリ: ../../dist"
echo ""
echo "🚀 準備完了! FontAwesome風aimojiパッケージを生成できます"